==> gorm-1.2.1.tar.gz: gorm-1.2.1/Palettes/4Data/GormTextViewAttributesInspector.h <==
/*
  GormTextViewAttributesInspector.h

   Copyright (C) 2001-2005 Free Software Foundation, Inc.

   Author:  Laurent Julliard <laurent@julliard-online.org>
   Date: Nov 2001
   
   This file is part of GNUstep.
   
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.
   
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
   
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02111 USA.
*/

/*
  July 2005 : Spilt inspector in separate classes.
  Always use ok: revert: methods
  Clean up
  Author : Fabien Vallon <fabien@sonappart.net>
*/

#ifndef INCLUDED_GormTextViewAttributesInspector_h
#define INCLUDED_GormTextViewAttributesInspector_h

#include <InterfaceBuilder/IBInspector.h>

@class NSColorWell;
@class NSMatrix;

@interface GormTextViewAttributesInspector : IBInspector
{
  NSColorWell *backgroundColorWell;
  NSColorWell *textColorWell;
  NSMatrix *borderMatrix;
  /* options */
  NSButton *selectableButton;
  NSButton *editableButton;
  NSButton *multipleFontsButton;
  NSButton *graphicsButton;  
}

@end

#endif /* INCLUDED_GormTextViewAttributesInspector_h */

==> gorm-1.3.1.tar.gz: gorm-1.3.1/Palettes/4Data/GormTextViewAttributesInspector.h <==
/*
  GormTextViewAttributesInspector.h

   Copyright (C) 2001-2005 Free Software Foundation, Inc.

   Author:  Laurent Julliard <laurent@julliard-online.org>
   Date: Nov 2001
   
   This file is part of GNUstep.
   
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 3 of the License, or
   (at your option) any later version.
   
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
   
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02111 USA.
*/

/*
  July 2005 : Spilt inspector in separate classes.
  Always use ok: revert: methods
  Clean up
  Author : Fabien Vallon <fabien@sonappart.net>
*/

#ifndef INCLUDED_GormTextViewAttributesInspector_h
#define INCLUDED_GormTextViewAttributesInspector_h

#include <InterfaceBuilder/InterfaceBuilder.h>

@class NSColorWell;
@class NSMatrix;

@interface GormTextViewAttributesInspector : IBInspector
{
  NSColorWell *backgroundColorWell;
  NSColorWell *textColorWell;
  NSMatrix *borderMatrix;
  /* options */
  NSButton *selectableButton;
  NSButton *editableButton;
  NSButton *multipleFontsButton;
  NSButton *graphicsButton;
  NSButton *undoButton;
  NSButton *findPanelButton;
}

@end

#endif /* INCLUDED_GormTextViewAttributesInspector_h */
